[PATCH v5 2/6] tpm: rename 'storagepath' to 'source_path'

marcandre.lureau@redhat.com posted 6 patches 1 month, 1 week ago
[PATCH v5 2/6] tpm: rename 'storagepath' to 'source_path'
Posted by marcandre.lureau@redhat.com 1 month, 1 week ago
From: Marc-André Lureau <marcandre.lureau@redhat.com>

Mechanically replace existing 'storagepath' with 'source_path', as the
following patches introduce <source path='..'> configuration.

Signed-off-by: Marc-André Lureau <marcandre.lureau@redhat.com>
Reviewed-by: Stefan Berger <stefanb@linux.ibm.com>
---
 src/conf/domain_conf.c          |  2 +-
 src/conf/domain_conf.h          |  2 +-
 src/qemu/qemu_tpm.c             | 46 ++++++++++++++++-----------------
 src/security/security_selinux.c |  6 ++---
 4 files changed, 28 insertions(+), 28 deletions(-)

diff --git a/src/conf/domain_conf.c b/src/conf/domain_conf.c
index 6d7dee7956..284a3815b3 100644
--- a/src/conf/domain_conf.c
+++ b/src/conf/domain_conf.c
@@ -3461,7 +3461,7 @@ void virDomainTPMDefFree(virDomainTPMDef *def)
         break;
     case VIR_DOMAIN_TPM_TYPE_EMULATOR:
         virObjectUnref(def->data.emulator.source);
-        g_free(def->data.emulator.storagepath);
+        g_free(def->data.emulator.source_path);
         g_free(def->data.emulator.logfile);
         virBitmapFree(def->data.emulator.activePcrBanks);
         break;
diff --git a/src/conf/domain_conf.h b/src/conf/domain_conf.h
index a15af4fae3..6b27322e3e 100644
--- a/src/conf/domain_conf.h
+++ b/src/conf/domain_conf.h
@@ -1478,7 +1478,7 @@ struct _virDomainTPMDef {
         struct {
             virDomainTPMVersion version;
             virDomainChrSourceDef *source;
-            char *storagepath;
+            char *source_path;
             char *logfile;
             unsigned int debug;
             unsigned char secretuuid[VIR_UUID_BUFLEN];
diff --git a/src/security/security_selinux.c b/src/security/security_selinux.c
index 8f567d5488..18daa521d1 100644
--- a/src/security/security_selinux.c
+++ b/src/security/security_selinux.c
@@ -3726,7 +3726,7 @@ virSecuritySELinuxSetTPMLabels(virSecurityManager *mgr,
 
         if (setTPMStateLabel) {
             ret = virSecuritySELinuxSetFileLabels(mgr,
-                                                  def->tpms[i]->data.emulator.storagepath,
+                                                  def->tpms[i]->data.emulator.source_path,
                                                   seclabel);
         }
 
@@ -3756,14 +3756,14 @@ virSecuritySELinuxRestoreTPMLabels(virSecurityManager *mgr,
 
         if (restoreTPMStateLabel) {
             ret = virSecuritySELinuxRestoreFileLabels(mgr,
-                                                      def->tpms[i]->data.emulator.storagepath);
+                                                      def->tpms[i]->data.emulator.source_path);
         } else {
             /* Even if we're not restoring the original label for the
              * TPM state directory, we should still forget any
              * remembered label so that a subsequent attempt at TPM
              * startup will not fail due to the state directory being
              * considered as still in use */
-            virSecuritySELinuxForgetLabels(def->tpms[i]->data.emulator.storagepath);
+            virSecuritySELinuxForgetLabels(def->tpms[i]->data.emulator.source_path);
         }
 
         if (ret == 0 &&
diff --git a/src/qemu/qemu_tpm.c b/src/qemu/qemu_tpm.c
index 749e4232b9..2d9cd59643 100644
--- a/src/qemu/qemu_tpm.c
+++ b/src/qemu/qemu_tpm.c
@@ -173,8 +173,8 @@ qemuTPMEmulatorCreateStorage(virDomainTPMDef *tpm,
                              uid_t swtpm_user,
                              gid_t swtpm_group)
 {
-    const char *storagepath = tpm->data.emulator.storagepath;
-    g_autofree char *swtpmStorageDir = g_path_get_dirname(storagepath);
+    const char *source_path = tpm->data.emulator.source_path;
+    g_autofree char *swtpmStorageDir = g_path_get_dirname(source_path);
 
     /* allow others to cd into this dir */
     if (g_mkdir_with_parents(swtpmStorageDir, 0711) < 0) {
@@ -186,19 +186,19 @@ qemuTPMEmulatorCreateStorage(virDomainTPMDef *tpm,
 
     *created = false;
 
-    if (!virFileExists(storagepath) ||
-        virDirIsEmpty(storagepath, true) > 0)
+    if (!virFileExists(source_path) ||
+        virDirIsEmpty(source_path, true) > 0)
         *created = true;
 
-    if (virDirCreate(storagepath, 0700, swtpm_user, swtpm_group,
+    if (virDirCreate(source_path, 0700, swtpm_user, swtpm_group,
                      VIR_DIR_CREATE_ALLOW_EXIST) < 0) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        _("Could not create directory %1$s as %2$u:%3$d"),
-                       storagepath, swtpm_user, swtpm_group);
+                       source_path, swtpm_user, swtpm_group);
         return -1;
     }
 
-    if (virFileChownFiles(storagepath, swtpm_user, swtpm_group) < 0)
+    if (virFileChownFiles(source_path, swtpm_user, swtpm_group) < 0)
         return -1;
 
     return 0;
@@ -214,7 +214,7 @@ qemuTPMEmulatorCreateStorage(virDomainTPMDef *tpm,
 static void
 qemuTPMEmulatorDeleteStorage(virDomainTPMDef *tpm)
 {
-    g_autofree char *path = g_path_get_dirname(tpm->data.emulator.storagepath);
+    g_autofree char *path = g_path_get_dirname(tpm->data.emulator.source_path);
 
     ignore_value(virFileDeleteTree(path));
 }
@@ -343,7 +343,7 @@ qemuTPMVirCommandAddEncryption(virCommand *cmd,
 /*
  * qemuTPMEmulatorRunSetup
  *
  * @storagepath: path to the directory for TPM state
  * @vmname: the name of the VM
  * @vmuuid: the UUID of the VM
  * @privileged: whether we are running in privileged mode
@@ -360,7 +360,7 @@ qemuTPMVirCommandAddEncryption(virCommand *cmd,
  * certificates for it.
  */
 static int
-qemuTPMEmulatorRunSetup(const char *storagepath,
+qemuTPMEmulatorRunSetup(const char *source_path,
                         const char *vmname,
                         const unsigned char *vmuuid,
                         bool privileged,
@@ -413,7 +413,7 @@ qemuTPMEmulatorRunSetup(const char *storagepath,
 
     if (!incomingMigration) {
         virCommandAddArgList(cmd,
-                             "--tpm-state", storagepath,
+                             "--tpm-state", source_path,
                              "--vmid", vmid,
                              "--logfile", logfile,
                              "--createek",
@@ -424,7 +424,7 @@ qemuTPMEmulatorRunSetup(const char *storagepath,
                              NULL);
     } else {
         virCommandAddArgList(cmd,
-                             "--tpm-state", storagepath,
+                             "--tpm-state", source_path,
                              "--logfile", logfile,
                              "--overwrite",
                              NULL);
@@ -465,7 +465,7 @@ qemuTPMPcrBankBitmapToStr(virBitmap *activePcrBanks)
  * qemuTPMEmulatorReconfigure
  *
  *
  * @storagepath: path to the directory for TPM state
  * @swtpm_user: The userid to switch to when setting up the TPM;
  *              typically this should be the uid of 'tss' or 'root'
  * @swtpm_group: The group id to switch to
@@ -478,7 +478,7 @@ qemuTPMPcrBankBitmapToStr(virBitmap *activePcrBanks)
  * Reconfigure the active PCR banks of a TPM 2.
  */
 static int
-qemuTPMEmulatorReconfigure(const char *storagepath,
+qemuTPMEmulatorReconfigure(const char *source_path,
                            uid_t swtpm_user,
                            gid_t swtpm_group,
                            virBitmap *activePcrBanks,
@@ -510,7 +510,7 @@ qemuTPMEmulatorReconfigure(const char *storagepath,
         return -1;
 
     virCommandAddArgList(cmd,
-                         "--tpm-state", storagepath,
+                         "--tpm-state", source_path,
                          "--logfile", logfile,
                          "--pcr-banks", activePcrBanksStr,
                          "--reconfigure",
@@ -570,7 +570,7 @@ qemuTPMEmulatorBuildCommand(virDomainTPMDef *tpm,
     /* Do not create storage and run swtpm_setup on incoming migration over
      * shared storage
      */
-    on_shared_storage = virFileIsSharedFS(tpm->data.emulator.storagepath, sharedFilesystems) == 1;
+    on_shared_storage = virFileIsSharedFS(tpm->data.emulator.source_path, sharedFilesystems) == 1;
     if (incomingMigration && on_shared_storage)
         create_storage = false;
 
@@ -582,7 +582,7 @@ qemuTPMEmulatorBuildCommand(virDomainTPMDef *tpm,
         secretuuid = tpm->data.emulator.secretuuid;
 
     if (created &&
-        qemuTPMEmulatorRunSetup(tpm->data.emulator.storagepath, vmname, vmuuid,
+        qemuTPMEmulatorRunSetup(tpm->data.emulator.source_path, vmname, vmuuid,
                                 privileged, swtpm_user, swtpm_group,
                                 tpm->data.emulator.logfile,
                                 tpm->data.emulator.version,
@@ -590,7 +590,7 @@ qemuTPMEmulatorBuildCommand(virDomainTPMDef *tpm,
         goto error;
 
     if (!incomingMigration &&
-        qemuTPMEmulatorReconfigure(tpm->data.emulator.storagepath,
+        qemuTPMEmulatorReconfigure(tpm->data.emulator.source_path,
                                    swtpm_user, swtpm_group,
                                    tpm->data.emulator.activePcrBanks,
                                    tpm->data.emulator.logfile,
@@ -610,7 +610,7 @@ qemuTPMEmulatorBuildCommand(virDomainTPMDef *tpm,
 
     virCommandAddArg(cmd, "--tpmstate");
     virCommandAddArgFormat(cmd, "dir=%s,mode=0600",
-                           tpm->data.emulator.storagepath);
+                           tpm->data.emulator.source_path);
 
     virCommandAddArg(cmd, "--log");
     if (tpm->data.emulator.debug != 0)
@@ -723,8 +723,8 @@ qemuTPMEmulatorInitPaths(virDomainTPMDef *tpm,
 
     virUUIDFormat(uuid, uuidstr);
 
-    if (!tpm->data.emulator.storagepath &&
-        !(tpm->data.emulator.storagepath =
+    if (!tpm->data.emulator.source_path &&
+        !(tpm->data.emulator.source_path =
             qemuTPMEmulatorStorageBuildPath(swtpmStorageDir, uuidstr,
                                             tpm->data.emulator.version)))
         return -1;
@@ -759,7 +759,7 @@ qemuTPMEmulatorCleanupHost(virQEMUDriver *driver,
      * storage.
      */
     if (outgoingMigration &&
-        virFileIsSharedFS(tpm->data.emulator.storagepath, cfg->sharedFilesystems) == 1)
+        virFileIsSharedFS(tpm->data.emulator.source_path, cfg->sharedFilesystems) == 1)
         return;
 
     /*
@@ -1040,7 +1040,7 @@ qemuTPMHasSharedStorage(virQEMUDriver *driver,
 
         switch (tpm->type) {
         case VIR_DOMAIN_TPM_TYPE_EMULATOR:
-            return virFileIsSharedFS(tpm->data.emulator.storagepath,
+            return virFileIsSharedFS(tpm->data.emulator.source_path,
                                      cfg->sharedFilesystems) == 1;
         case VIR_DOMAIN_TPM_TYPE_PASSTHROUGH:
         case VIR_DOMAIN_TPM_TYPE_EXTERNAL:
@@ -343,7 +343,7 @@ qemuTPMVirCommandAddEncryption(virCommand *cmd,
  * qemuTPMEmulatorRunSetup
  *
- * @storagepath: path to the directory for TPM state
+ * @source_path: path to the directory for TPM state
  * @vmname: the name of the VM
  * @vmuuid: the UUID of the VM
@@ -465,7 +465,7 @@ qemuTPMPcrBankBitmapToStr(virBitmap *activePcrBanks)
  *
  *
- * @storagepath: path to the directory for TPM state
+ * @source_path: path to the directory for TPM state
  * @swtpm_user: The userid to switch to when setting up the TPM;
  *              typically this should be the uid of 'tss' or 'root'
-- 
2.47.0